==> hs-bio-0.5.1.tbz: lib/ghc-7.0.4/cabal/bio-0.5.1/register.sh <==
#!/bin/sh
echo 'name: bio
version: 0.5.1
id: bio-0.5.1-65a16bac78750843bd2ea4003de2fb1c

license: LGPL
copyright:
maintainer: ketil@malde.org
stability:
homepage: http://biohaskell.org/Libraries/Bio
package-url:
description: This is a collection of data structures and algorithms
             useful for building bioinformatics-related tools
             and utilities.
             .
             Current list of features includes: a Sequence data type supporting
             protein and nucleotide sequences and conversion between them.  As of version
             0.4, different kinds of sequence have different types.  Support for quality
             data, reading and writing Fasta formatted files, reading TwoBit and
             phd formats, and Roche/454 SFF files.  Rudimentary (i.e. unoptimized) support
             for doing alignments - including dynamic adjustment of scores based on sequence quality.
             Also Blast output parsing.  Partly implemented single linkage clustering, and
             multiple alignment.  Reading Gene Ontology (GO) annotations (GOA) and
             definitions\/hierarchy.
             .
             The Darcs repository is at: <http://malde.org/~ketil/biohaskell/biolib>.
category: Bioinformatics
author: Ketil Malde
exposed: True
exposed-modules: Bio.Sequence Bio.Sequence.SeqData
                 Bio.Sequence.Fasta Bio.Sequence.FastQ Bio.Sequence.TwoBit
                 Bio.Sequence.Phd Bio.Sequence.Entropy Bio.Sequence.HashWord
                 Bio.Sequence.GOA Bio.Sequence.GeneOntology Bio.Sequence.KEGG
                 Bio.Sequence.AminoProperties Bio.Sequence.SFF Bio.Sequence.SFF_name
                 Bio.Sequence.SFF_filters Bio.Alignment.BlastData
                 Bio.Alignment.BlastFlat Bio.Alignment.Blast Bio.Alignment.BlastXML
                 Bio.Alignment.AlignData Bio.Alignment.Matrices Bio.Alignment.SAlign
                 Bio.Alignment.AAlign Bio.Alignment.QAlign Bio.Alignment.Multiple
                 Bio.Alignment.ACE Bio.Alignment.Bowtie Bio.Alignment.Soap
                 Bio.Alignment.BED Bio.Alignment.PSL Bio.Clustering Bio.Util
                 Bio.Util.Parsex Bio.Location.Strand Bio.Location.Position
                 Bio.Location.ContigLocation Bio.Location.Location
                 Bio.Location.LocMap Bio.Location.OnSeq Bio.Location.SeqLocation
                 Bio.Location.SeqLocMap Bio.GFF3.Escape Bio.GFF3.Feature
                 Bio.GFF3.FeatureHier Bio.GFF3.FeatureHierSequences Bio.GFF3.SGD
hidden-modules:
import-dirs: /usr/local/lib/ghc-7.0.4/cabal/bio-0.5.1
library-dirs: /usr/local/lib/ghc-7.0.4/cabal/bio-0.5.1
              /usr/local/lib
hs-libraries: HSbio-0.5.1
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: QuickCheck-2.4.1.1-b24a010efafa7347b56b3001ff218a37
         array-0.3.0.2-ecfce597e0f16c4cd1df0e1d22fd66d4
         base-4.3.1.0-93a63ba911a7eac625848432374f7fee
         binary-0.5.0.2-9ef1f923d941cd09138d709aca55a66b
         bytestring-0.9.1.10-8fbcae7fd1f192307195284611c786a2
         containers-0.4.0.0-18deac99a132f04751d862b77aab136e
         directory-1.1.0.0-ccdcf043bf8bcec9518fbfad880579a5
         mtl-2.0.1.0-9763a8821c812a910d327bad2c0d23b2
         old-time-1.0.0.6-37d6575186c36059fbc372c289dbddd4
         parallel-3.1.0.1-6eaa564e1ef1537bc88ad1fea6c90fe2
         parsec-3.1.1-b00f60a5e51d506a52e3c7ef2ba3e9f9
         process-1.0.1.5-4cab1bf0666275ac101dd48c7565b64c
         random-1.0.0.3-57524486875e0c4c260dd22788921013
         tagsoup-0.12.6-e8829179f55793600712a547a52d125d
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.4/cabal/bio-0.5.1/html/bio.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.4/cabal/bio-0.5.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-bio-0.5.2_1.tbz: lib/ghc-7.4.1/cabal/bio-0.5.2/register.sh <==
#!/bin/sh
echo 'name: bio
version: 0.5.2
id: bio-0.5.2-6d43378011b77618fe1213a5bb93320f

license: LGPL
copyright:
maintainer: ketil@malde.org
stability:
homepage: http://biohaskell.org/Libraries/Bio
package-url:
synopsis: A bioinformatics library
description: This is a collection of data structures and algorithms
             useful for building bioinformatics-related tools
             and utilities.
             .
             Current list of features includes: a Sequence data type supporting
             protein and nucleotide sequences and conversion between them.  As of version
             0.4, different kinds of sequence have different types.  Support for quality
             data, reading and writing Fasta formatted files, reading TwoBit and
             phd formats, and Roche/454 SFF files.  Rudimentary (i.e. unoptimized) support
             for doing alignments - including dynamic adjustment of scores based on sequence quality.
             Also Blast output parsing.  Partly implemented single linkage clustering, and
             multiple alignment.  Reading Gene Ontology (GO) annotations (GOA) and
             definitions\/hierarchy.
             .
             The Darcs repository is at: <http://malde.org/~ketil/biohaskell/biolib>.
category: Bioinformatics
author: Ketil Malde
exposed: True
exposed-modules: Bio.Sequence Bio.Sequence.SeqData
                 Bio.Sequence.Fasta Bio.Sequence.FastQ Bio.Sequence.TwoBit
                 Bio.Sequence.Phd Bio.Sequence.Entropy Bio.Sequence.HashWord
                 Bio.Sequence.GOA Bio.Sequence.GeneOntology Bio.Sequence.KEGG
                 Bio.Sequence.AminoProperties Bio.Sequence.SFF Bio.Sequence.SFF_name
                 Bio.Sequence.SFF_filters Bio.Alignment.BlastData
                 Bio.Alignment.BlastFlat Bio.Alignment.Blast Bio.Alignment.BlastXML
                 Bio.Alignment.AlignData Bio.Alignment.Matrices Bio.Alignment.SAlign
                 Bio.Alignment.AAlign Bio.Alignment.QAlign Bio.Alignment.Multiple
                 Bio.Alignment.ACE Bio.Alignment.Bowtie Bio.Alignment.Soap
                 Bio.Alignment.BED Bio.Alignment.PSL Bio.Clustering Bio.Util
                 Bio.Util.Parsex Bio.Location.Strand Bio.Location.Position
                 Bio.Location.ContigLocation Bio.Location.Location
                 Bio.Location.LocMap Bio.Location.OnSeq Bio.Location.SeqLocation
                 Bio.Location.SeqLocMap Bio.GFF3.Escape Bio.GFF3.Feature
                 Bio.GFF3.FeatureHier Bio.GFF3.FeatureHierSequences Bio.GFF3.SGD
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.1/cabal/bio-0.5.2
library-dirs: /usr/local/lib/ghc-7.4.1/cabal/bio-0.5.2
              /usr/local/lib
hs-libraries: HSbio-0.5.2
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: QuickCheck-2.4.2-6294b70bb1126d365d60ef99cef6eec4
         array-0.4.0.0-0b32f6f98c0297dbb0e5cfc0087bd1f0
         base-4.5.0.0-1a022b3476300ed3e5bfdd46dd7221d0
         binary-0.5.1.0-7100f639c59068a2d40264555b8517e7
         bytestring-0.9.2.1-e2bcd9910229fcb291a3a8dd6f79f7fe
         containers-0.4.2.1-7c54595400348f577b3b4a45691c5afd
         directory-1.1.0.2-295465228776dcfcc680f61dc2cbcb59
         mtl-2.1.1-ae9b44386a2528180e60dcf2412689c0
         old-time-1.1.0.0-681e9789e8750358e65a9448b60ba641
         parallel-3.2.0.2-e513f17942b2ee5c41cde1ef99dea764
         parsec-3.1.2-5d1caf26bfa3bdcc843000f0803b4975
         process-1.1.0.1-91185c964ab744c1f3cbca1863d2ba45
         random-1.0.1.1-3bece392c9f5221263ed25c90c28e1ec
         tagsoup-0.12.6-29e813ea4b09c0061c25a107ef9b0cb6
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.1/cabal/bio-0.5.2/html/bio.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.1/cabal/bio-0.5.2/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
